@@ -1,4 +1,4 @@
-#!/usr/pkg/bin/python3.13
+#!/usr/local/bin/python3.12
 # -*- coding: utf-8 -*-
 
 # Run me like this: ./create_manpage_completions.py /usr/share/man/man{1,8}/* > man_completions.fish
@@ -793,6 +793,26 @@ def parse_manpage_at_path(manpage_path, output_directory):
     if CMDNAME in ignoredcommands:
         return
 
+    # Ignore some commands' gazillion man pages
+    # for subcommands - especially things we already have
+    ignored_prefixes = [
+        "bundle-",
+        "cargo-",
+        "ffmpeg-",
+        "flatpak-",
+        "git-",
+        "npm-",
+        "openssl-",
+        "ostree-",
+        "perf-",
+        "perl",
+        "pip-",
+        "zsh",
+    ]
+    for prefix in ignored_prefixes:
+        if CMDNAME.startswith(prefix):
+            return
+
     # Clear diagnostics
     global diagnostic_indent
     diagnostic_output[:] = []
@@ -831,12 +851,6 @@ def parse_manpage_at_path(manpage_path, output_directory):
 
     manpage = str(manpage)
 
-    # Ignore perl's gazillion man pages
-    ignored_prefixes = ["perl", "zsh"]
-    for prefix in ignored_prefixes:
-        if CMDNAME.startswith(prefix):
-            return
-
     # Ignore the millions of links to BUILTIN(1)
     if "BUILTIN 1" in manpage or "builtin.1" in manpage:
         return
@@ -1122,11 +1136,11 @@ if __name__ == "__main__":
         sys.exit(0)
 
     if not args.stdout and not args.directory:
-        # Default to ~/.local/share/fish/generated_completions/
+        # Default to ~/.cache/fish/generated_completions
         # Create it if it doesn't exist
-        xdg_data_home = os.getenv("XDG_DATA_HOME", "~/.local/share")
+        xdg_cache_home = os.getenv("XDG_CACHE_HOME", "~/.cache")
         args.directory = os.path.expanduser(
-            xdg_data_home + "/fish/generated_completions/"
+            xdg_cache_home + "/fish/generated_completions/"
         )
         try:
             os.makedirs(args.directory)
